==> mastapy-14.0.0b1.tar.gz: mastapy-14.0.0b1/mastapy/_private/_internal/implicit/enum_with_selected_value/force_display_option.py <==
"""Implementations of 'EnumWithSelectedValue' in Python.

As Python does not have an implicit operator, this is the next
best solution for implementing these types properly.
"""
from __future__ import annotations

from enum import Enum
from typing import TYPE_CHECKING

from mastapy._private.electric_machines.harmonic_load_data import _1425
from mastapy._private._internal import mixins
from mastapy._private._internal.python_net import python_net_import

_ARRAY = python_net_import("System", "Array")
_ENUM_WITH_SELECTED_VALUE = python_net_import(
    "SMT.MastaAPI.Utility.Property", "EnumWithSelectedValue"
)

if TYPE_CHECKING:
    from typing import List, Type, Any, TypeVar

    Self = TypeVar("Self", bound="EnumWithSelectedValue_ForceDisplayOption")


__docformat__ = "restructuredtext en"
__all__ = ("EnumWithSelectedValue_ForceDisplayOption",)


class EnumWithSelectedValue_ForceDisplayOption(mixins.EnumWithSelectedValueMixin, Enum):
    """EnumWithSelectedValue_ForceDisplayOption

    A specific implementation of 'EnumWithSelectedValue' for 'ForceDisplayOption' types.
    """

    __qualname__ = "ForceDisplayOption"

    @classmethod
    def wrapper_type(cls: "Type[EnumWithSelectedValue_ForceDisplayOption]") -> "Any":
        """Pythonnet type of this class.

        Note:
            This property is readonly.

        Returns:
            Any
        """
        return _ENUM_WITH_SELECTED_VALUE

    @classmethod
    def wrapped_type(
        cls: "Type[EnumWithSelectedValue_ForceDisplayOption]",
    ) -> "_1425.ForceDisplayOption":
        """Wrapped Pythonnet type of this class.

        Note:
            This property is readonly

        Returns:
            _1425.ForceDisplayOption
        """
        return _1425.ForceDisplayOption

    @classmethod
    def implicit_type(cls: "Type[EnumWithSelectedValue_ForceDisplayOption]") -> "Any":
        """Implicit Pythonnet type of this class.

        Note:
            This property is readonly.

        Returns:
            Any
        """
        return _1425.ForceDisplayOption.type_()

    @property
    def selected_value(self: "Self") -> "_1425.ForceDisplayOption":
        """mastapy._private.electric_machines.harmonic_load_data.ForceDisplayOption

        Note:
            This property is readonly.
        """
        return None

    @property
    def available_values(self: "Self") -> "List[_1425.ForceDisplayOption]":
        """List[mastapy._private.electric_machines.harmonic_load_data.ForceDisplayOption]

        Note:
            This property is readonly.
        """
        return None

==> mastapy-14.1.3.tar.gz: mastapy-14.1.3/mastapy/_private/_internal/implicit/enum_with_selected_value/force_display_option.py <==
"""Implementations of 'EnumWithSelectedValue' in Python.

As Python does not have an implicit operator, this is the next
best solution for implementing these types properly.
"""

from __future__ import annotations

from enum import Enum
from typing import TYPE_CHECKING

from mastapy._private._internal import mixins
from mastapy._private._internal.python_net import python_net_import
from mastapy._private.electric_machines.harmonic_load_data import _1437

_ARRAY = python_net_import("System", "Array")
_ENUM_WITH_SELECTED_VALUE = python_net_import(
    "SMT.MastaAPI.Utility.Property", "EnumWithSelectedValue"
)

if TYPE_CHECKING:
    from typing import Any, List, Type, TypeVar

    Self = TypeVar("Self", bound="EnumWithSelectedValue_ForceDisplayOption")


__docformat__ = "restructuredtext en"
__all__ = ("EnumWithSelectedValue_ForceDisplayOption",)


class EnumWithSelectedValue_ForceDisplayOption(mixins.EnumWithSelectedValueMixin, Enum):
    """EnumWithSelectedValue_ForceDisplayOption

    A specific implementation of 'EnumWithSelectedValue' for 'ForceDisplayOption' types.
    """

    __qualname__ = "ForceDisplayOption"

    @classmethod
    def wrapper_type(cls: "Type[EnumWithSelectedValue_ForceDisplayOption]") -> "Any":
        """Pythonnet type of this class.

        Note:
            This property is readonly.

        Returns:
            Any
        """
        return _ENUM_WITH_SELECTED_VALUE

    @classmethod
    def wrapped_type(
        cls: "Type[EnumWithSelectedValue_ForceDisplayOption]",
    ) -> "_1437.ForceDisplayOption":
        """Wrapped Pythonnet type of this class.

        Note:
            This property is readonly

        Returns:
            _1437.ForceDisplayOption
        """
        return _1437.ForceDisplayOption

    @classmethod
    def implicit_type(cls: "Type[EnumWithSelectedValue_ForceDisplayOption]") -> "Any":
        """Implicit Pythonnet type of this class.

        Note:
            This property is readonly.

        Returns:
            Any
        """
        return _1437.ForceDisplayOption.type_()

    @property
    def selected_value(self: "Self") -> "_1437.ForceDisplayOption":
        """mastapy.electric_machines.harmonic_load_data.ForceDisplayOption

        Note:
            This property is readonly.
        """
        return None

    @property
    def available_values(self: "Self") -> "List[_1437.ForceDisplayOption]":
        """List[mastapy.electric_machines.harmonic_load_data.ForceDisplayOption]

        Note:
            This property is readonly.
        """
        return None
